@@ -21,9 +21,17 @@ class Beacon:
     self.rabbitAutoconnect = False
     print("[Beacon] Setting up the routes...")
     self.setupServerRoutes()
+  
+  # Start the Beacon
+  def start(self):
     self.initRabbit()
     self.pulseThread = threading.Thread(target=self.servicePulse, args=())
     self.pulseThread.start()
+    print("[Beacon] Looking for devices on the local network...")
+    self.findServices()
+    self.displayServices()
+    print("[Beacon] Saying hello...")
+    self.sayHello()
 
   # Check the services pulse using a ping
   def servicePulse(self):
@@ -91,14 +99,6 @@ class Beacon:
       self.queues = {} # Clears the queues
       self.connection = None # Reset RabbitMQ
   
-  # Start the Beacon
-  def start(self):
-    print("[Beacon] Looking for devices on the local network...")
-    self.findServices()
-    self.displayServices()
-    print("[Beacon] Saying hello...")
-    self.sayHello()
-  
   # Say hello to announce our presence to other devices
   def sayHello(self):
     for deviceID in self.devices.keys():
@@ -210,3 +210,7 @@ class Beacon:
       print("[Beacon:buffer]", name, data)
       #self.bufferData(name, data)
 
+  def subscribe(self, name, callback):
+    channel = self.getQueue(name)
+    channel.basic_consume(queue=name, on_message_callback=callback, auto_ack=True)
+    channel.start_consuming()
\ No newline at end of file
